import json
from functools import lru_cache
from pathlib import Path
from typing import Any, Dict

PARALLELISM_DEFAULT = 4
PLUGIN_SETTINGS_FILE = Path("/etc/ucsschool/apis/id-broker/self-disclosure-api.json")


def load_settings(path: Path) -> Dict[str, Any]:
    try:
        with path.open() as settings_file:
            return json.load(settings_file)
    except (EnvironmentError, ValueError) as exc:
        raise ValueError(f"Missing, incomplete or malformed settings file '{path!s}': {exc!s}") from exc


@lru_cache(maxsize=1)
def kelvin_access_parallelism_setting(path: Path) -> int:
    json_settings = load_settings(path)
    try:
        return json_settings["kelvin_access_parallelism"]
    except KeyError:
        return PARALLELISM_DEFAULT
